version 8.0
log using chapter3.log, replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*     File-Name:  chapter3.do                                           *;
*     Date:       April 21, 2005                                        *;
*     Author:     SLN                                                   *;
*     Purpose:    Get results for Chapter 3 - electoral rules           *;
*                 (parliamentary democracies only)                      *;
*     Input File: chapter3.dta                                          *;
*     Output File: chapter3.log                                         *;
*     Data Output:                                                      *;
*     Previous file:                                                    *;
*     Machine:    Compaq                                                *;
*     ****************************************************************  *;
*     ****************************************************************  *;

use C:\datasets\chapter3.dta;

set more off;


*     ****************************************************************  *;
*              Information for Table 3.1                                *;
*     ****************************************************************  *;

sum pec;
sum pec if pec==1 & majoritarian==1;
sum pec if pec==0 & majoritarian==1;
sum pec if pec==1 & majoritarian==0;
sum pec if pec==0 & majoritarian==0;
sum vote_pec if majoritarian==1;
sum vote_pec if majoritarian==0;
sum enep if majoritarian==1;
sum enep if majoritarian==0;

*     ****************************************************************  *;
*              Information for Table 3.2 (Descriptive Statistics)       *;
*     ****************************************************************  *;

sum vote_pec;
sum perc_part;
sum enep;
sum threshold;

*     ****************************************************************  *;
*                   Results for Table 3.3                               *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*      Going to use panel-corrected  standard errors.  There are some   *;
*      repeated time values in the panel since some countries had       *;
*      two elections in the same year.  This causes problems for the    *;
*      computer. So I will drop one of the observations for these       *;
*      elections (5 elections dropped).                                 *;
*     ****************************************************************  *;

replace year=. if legelec==2;

tsset id year, yearly;

*     ****************************************************************  *;
*                   Signalling Model 1, full sample                     *;
*     ****************************************************************  *;

xtpcse vote_pec enep, pairwise;


*     ****************************************************************  *;
*       Unconditional Model 1, using Effective Threshold                *;
*     ****************************************************************  *;

xtpcse vote_pec enep threshold, pairwise;

*     ****************************************************************  *;
*          Conditional Model 1, using Effective Threshold               *;
*     ****************************************************************  *;

xtpcse vote_pec enep threshold enep_thresh, pairwise;


*     ****************************************************************  *;
*          Conditional Model 2, using Effective Threshold               *;
*     ****************************************************************  *;

xtpcse perc_part enep threshold enep_thresh, pairwise;

*     ****************************************************************  *;
*               Now create some figures                                 *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*         Graph of Conditional Model 1, using Effective Threshold       *;
*           This is figure 3.1 in Chapter 3                             *;
*     ****************************************************************  *;

xtpcse vote_pec threshold enep enep_thresh, pairwise;

generate JH=((_n-1)/10);    
replace JH=. if _n>100;
matrix b=e(b);
matrix V=e(V);
scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
gen conb=b1+b3*JH if _n<100;
gen conse=sqrt(varb1+varb3*JH^2+2*covb1b3*JH)  if _n<100;
set more off;
gen a=1.96*conse;
gen top=conb+a;
gen bottom=conb-a;
set textsize 100;

graph twoway   line conb JH, clwidth(medium) clcolor(blue) clcolor(black)
        ||  line top  JH, clpattern(dash) clwidth(thin) clcolor(black)
        ||  line bottom JH, clpattern(dash) clwidth(thin) clcolor(black)
        ||  ,   
            xlabel(0 1 2 3 4 5 6 7 8 9 10, labsize(2.5)) 
            ylabel(-5 0 5, labsize(2.5))
            yscale(noline)
            xscale(noline)
            legend(off)
        yline(0, lcolor(black)) yline(-5 5, lcolor(white))  
            xtitle(Effective Number of Parties, size(3)  )
        xsca(titlegap(2))
        ysca(titlegap(2))
            ytitle("Marginal Effect of Effective Threshold", size(3))
        scheme(s1mono) graphregion(fcolor(white));

translate @Graph c:\data\chapter3_1a.wmf, replace;

*     ****************************************************************  *;
*       An increase in the effective electoral threshold will have a    *;
*       positive and significant effect on the percentage of votes      *;
*       for a pre-electoral coalition when the effective number of      *;
*       parties is greater than 3.5 (47.5 percent of the sample).       *;
*     ****************************************************************  *;

drop JH conb conse a top bottom;

*     ****************************************************************  *;
*         Graph of Conditional Model 2, using Effective Threshold       *;
*           This is Figure 3.1b in Chapter 3                            *;
*     ****************************************************************  *;

xtpcse perc_part threshold enep enep_thresh, pairwise;

generate JH=((_n-1)/10);    
replace JH=. if _n>100;
matrix b=e(b);
matrix V=e(V);
scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
gen conb=b1+b3*JH if _n<100;
gen conse=sqrt(varb1+varb3*JH^2+2*covb1b3*JH)  if _n<100;
set more off;
gen a=1.96*conse;
gen top=conb+a;
gen bottom=conb-a;
set textsize 100;

graph twoway   line conb JH, clwidth(medium) clcolor(blue) clcolor(black)
        ||  line top  JH, clpattern(dash) clwidth(thin) clcolor(black)
        ||  line bottom JH, clpattern(dash) clwidth(thin) clcolor(black)
        ||  ,   
            xlabel(0 1 2 3 4 5 6 7 8 9 10, labsize(2.5)) 
            ylabel(-5 0 5, labsize(2.5))
            yscale(noline)
            xscale(noline)
            legend(off)
        yline(0, lcolor(black)) yline(-5 5, lcolor(white))  
           xtitle(Effective Number of Parties, size(3)  )
        xsca(titlegap(2))
        ysca(titlegap(2))
            ytitle("Marginal Effect of Effective Threshold", size(3))
        scheme(s1mono) graphregion(fcolor(white));

translate @Graph c:\data\chapter3_1b.wmf, replace;

*     ****************************************************************  *;
*       An increase in the effective electoral threshold will have a    *;
*       positive and significant effect on the percentage of parties    *;
*       in a pre-electoral coalition when the effective number of       *;
*       parties is greater than 3.4 (56.0 percent of the sample).       *;
*     ****************************************************************  *;

drop JH conb conse a top bottom;

log close;
exit;
