version 8.0
log using fig6_3.log, replace
#delimit ;


*************************************************************;
*     File-Name:  fig6_3.do                                 *;
*     Date:       March 8, 2006                             *;
*     Author:     SNG                                       *;
*     Purpose: produce figure for asymmetry variable        *;
*     Input File: chapter6.dta                              *;
*     Output File: fig6_3.log                               *;
*     Machine: Dell                                       *;
*************************************************************;

use C:\DATA\chapter6.dta;

set more off;


*************************************************************;
*                   Create some variables                   *;
*************************************************************;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;

generate seatshare_2 = seatshare*seatshare;

gen polarization_threshold = polarization*threshold;

gen asymmetry = seatlag1 /(seatlag1 + seatlag2);

replace asymmetry = 1-asymmetry if asymmetry<.5;

replace asymmetry = 2*(asymmetry - .5);

gen asym_seat =  asymmetry*seatshare;

*************************************************************;
*   Probit 2: Random effects probit, by election.           *;
*************************************************************;

xtprobit pec incompatibility polarization threshold
             polarization_threshold seatshare seatshare_2  
             asymmetry asym_seat, re i (ident);

preserve;
drawnorm SN_b1-SN_b10, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;
postfile mypost prob_hat lo hi prob_hat1 lo1 hi1 diff_hat lod hid rel_risk lor hir
            using sim , replace;
            noisily display "start";

local a=0 ;
while `a' <= 101 { ;

quietly display "got here";
quietly {;


scalar h_incompatibility= 24.41;
scalar h_polarization=28.58;
scalar h_threshold=8.59;
scalar h_polarization_threshold=(h_polarization*h_threshold);
scalar h_seatshare=31.37;
scalar h_seatshare_2=(h_seatshare*h_seatshare);
scalar h_asymmetry=.545;
scalar h_constant=1;


    generate x_betahat  = SN_b1*h_incompatibility
                            + SN_b2*h_polarization
                            + SN_b3*h_threshold
                            + SN_b4*h_polarization_threshold
                            + SN_b5*`a'
                            + SN_b6*`a'*`a'
                            + SN_b7*h_asymmetry
                            + SN_b8*h_asymmetry*`a'
                            + SN_b9*h_constant;
    
    
    generate x_betahat1  = SN_b1*h_incompatibility
                            + SN_b2*h_polarization
                            + SN_b3*h_threshold
                            + SN_b4*h_polarization_threshold
                            + SN_b5*`a'
                            + SN_b6*`a'*`a'
                            + SN_b7*(h_asymmetry+.01)
                            + SN_b8*`a'*(h_asymmetry+.01)
                            + SN_b9*h_constant;
    
    
    gen prob =norm(x_betahat);
    gen prob1=norm(x_betahat1);
    gen diff=prob1-prob;
    gen risk=prob1/prob;
    
    egen probhat =mean(prob);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);
    egen relrisk=mean(risk);
    
    tempname prob_hat lo hi prob_hat1 lo1 hi1 diff_hat lod hid rel_risk lor hir;  

    _pctile prob, p(2.5,97.5) ;
    scalar `lo' = r(r1);
    scalar `hi' = r(r2);  
    
    _pctile prob1, p(2.5,97.5);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(2.5,97.5);
    scalar `lod'= r(r1);
    scalar `hid'= r(r2);  

    _pctile risk, p(2.5,97.5);
    scalar `lor'= r(r1);
    scalar `hir'= r(r2);  
    
    scalar `prob_hat'=probhat;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
    scalar `rel_risk'=relrisk;
    
    post mypost (`prob_hat') (`lo') (`hi') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`lod') (`hid') (`rel_risk') (`lor') (`hir') ;
    };      
    drop x_betahat x_betahat1 prob prob1 diff probhat probhat1 diffhat risk relrisk;
    local a=`a'+ 1 ;
    display "." _c;
} ;
display "";
postclose mypost;

use sim, clear;

gen seatshare = _n-1;

graph twoway line diff_hat seatshare, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line lod seatshare, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line hid seatshare, clpattern(dash) clwidth(thin) clcolor(black)
        ||  ,   
            xlabel(0 10 20 30 40 50 60 70 80 90 100, labsize(3)) 
            ylabel(-.001 -.0005 -.0001 0 .0001, labsize(3))
            yscale(noline)
            xscale(noline)
            yline(0)
            yline(-.001 -.0005 -.0001 .0001, lcolor(white))
            legend(off)
            xtitle(Coalition Seat Share, size(3.5)  )
        xsca(titlegap(2))
        ysca(titlegap(2))
            ytitle("Marginal Effect of Asymmetry", size(3.5))
        scheme(s2mono) graphregion(fcolor(white));


translate @Graph c:\data\chap6_asymmetry.wmf, replace;


*************************************************************;
* Prob_hat is always positive and significant, max at 32.   *;
* Diff_hat is negative and significant when seatshare>11.   *;
* This is observations 696-3574, or 80.6 percent of sample  *;
* with values for seatshare. (Remember that there are       *;
* missing vars, due to lagged values used to create         *;
* seatshare). If all 4460 obs are considered, then diff_hat *;
* is negative and significant for 64.6 percent of the sample*;
*************************************************************;

*************************************************************;
*************************************************************;

log close;
