version 8.0
log using bargaindelay.log, replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*     File-Name:  bargaindelay.do                                       *;
*     Date:       March 30, 2005                                        *;
*     Author:     SNG                                                   *;
*     Purpose:    analyze interaction term on post-election govts only  *;
*                   use investiture measure from CCPD dataset           *;
*     Data Used:  coalition.dta                                         *;
*     Output File:    bargaindelay.log                                  *;
*     Machine:    laptop (compaq)                                       *;
*     ****************************************************************  *;
*     ****************************************************************  *;

**********************************************************************  *;
*   "bargain2" measures the number of days spent bargaining over        *;
*   forming the cabinet.  This variable comes from Muller and Strom     *;
*   (CCPD dataset).                                                     *;
**********************************************************************  *;

set more off;

use C:\datasets\coalition.dta;

**********************************************************************  *;
*                   Create some variables                               *;
**********************************************************************  *;

gen pec_parties = pec * govtparties;
gen minority = 0;
replace minority=1 if majority2==0;
gen invest_minority = investiture*minority;

sum investiture pec govtparties range minority if postelection==1;

stset bargain2;


**********************************************************************  *;
*   Calculate effect of pre-electoral coalitions on bargaining length   *;
*   over full range of the number of government parties                 *;
**********************************************************************  *;


**********************************************************************  *;
*   Next two models generate results listed in Table 7.3                *;
**********************************************************************  *;

stcox investiture minority invest_minority govtparties pec pec_parties range previnoffice if postelection==1, efron nohr;



streg investiture minority invest_minority govtparties pec pec_parties range previnoffice if postelection==1, dist(weib) nohr;


**********************************************************************  *;
*           The following code creates Figure 7.1                       *;
**********************************************************************  *;

matrix p=e(aux_p);
scalar p1 = p[1,1];

preserve;
drawnorm SN_b1-SN_b10, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;
postfile mypost dur_hat lo hi dur_hat1 lo1 hi1 diff_hat lod hid rel_risk lor hir
            using sim , replace;
            noisily display "start";

local a=0 ;
while `a' <= 5 { ;

quietly display "got here";
quietly {;

scalar h_investiture = 0; 
scalar h_minority = 0;
scalar h_range = 17.30409;
scalar h_previnoffice = 0;
scalar h_constant = 1;

    generate xb0  = SN_b1*h_investiture
                    + SN_b2*h_minority
                    + SN_b3*h_minority*h_investiture
                    + SN_b4*`a'
                    + SN_b5*0
                    + SN_b6*0*`a'
                    + SN_b7*h_range
                    + SN_b8*h_previnoffice
                    + SN_b9*h_constant; 
    
    generate xb1  = SN_b1*h_investiture
                    + SN_b2*h_minority
                    + SN_b3*h_minority*h_investiture
                    + SN_b4*`a'
                    + SN_b5*1
                    + SN_b6*1*`a'
                    + SN_b7*h_range
                    + SN_b8*h_previnoffice                    
                    + SN_b9*h_constant; 

        
    gen duration0 = (1/exp(xb0)^(1/p1)) * (exp(lngamma(1+(1/p1)))) ;
    gen duration1 = (1/exp(xb1)^(1/p1)) * (exp(lngamma(1+(1/p1)))) ;
    gen diff=duration1-duration0;
    gen risk=duration1/duration0;
    
    egen durhat =mean(duration0);
    egen durhat1=mean(duration1);
    egen diffhat=mean(diff);
    egen relrisk=mean(risk);
    
    tempname dur_hat lo hi dur_hat1 lo1 hi1 diff_hat lod hid rel_risk lor hir;  

    _pctile duration0, p(2.5,97.5);
    scalar `lo' = r(r1);
    scalar `hi' = r(r2);  
    
    _pctile duration1, p(2.5,97.5);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(2.5,97.5);
    scalar `lod'= r(r1);
    scalar `hid'= r(r2);  

    _pctile risk, p(2.5,97.5);
    scalar `lor'= r(r1);
    scalar `hir'= r(r2);  
    
    scalar `dur_hat'=durhat;
    scalar `dur_hat1'=durhat1;
    scalar `diff_hat'=diffhat;
    scalar `rel_risk'=relrisk;
    
    post mypost (`dur_hat') (`lo') (`hi') (`dur_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`lod') (`hid') (`rel_risk') (`lor') (`hir') ;
    };      
    drop xb0 xb1 duration0 duration1 diff durhat durhat1 diffhat risk relrisk;
    local a=`a'+ .1 ;
    display "." _c;
} ;
display "";
postclose mypost;

use sim, clear;

gen parties = _n-1;


graph twoway line diff_hat parties, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line lod parties, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line hid parties, clpattern(dash) clwidth(thin) clcolor(black)
        ||  ,   
            xlabel(0 10 20 30 40 50, labsize(3)) 
            ylabel(-100 -50  0 50 100, labsize(3))
            yscale(noline)
            xscale(noline)
            yline(0)
            yline(-100 -50  50 100, lcolor(white))
            legend(off)
            xtitle(Number of Government Parties, size(3.5)  )
        xsca(titlegap(2))
        ysca(titlegap(2))
            ytitle("Marginal Effect of PECs on Expected Duration", size(3.5))
        scheme(s2mono) graphregion(fcolor(white));

graph export c:\datasets\bargaindelay.eps, replace;
translate @Graph c:\datasets\bargaindelay.wmf, replace;

*  ******************************************************************** *;
*    Marginal effect of pre-electoral coalitions is negative and        *;
*    significant when the number of parties is greater than 3.          *;
*    The marginal effect of pre-electoral coalitions on the expected    *;
*    duration of bargaining is negative and significant when the number *;
*    of parties is greater than 2.                                      *;
*    If all partisan governments are considered, cabinets with 3 or     *;
*    more parties make up 31.8 percent.  If only coalition governments  *;
*    are considered, 50.4 percent have 3 or more parties.               *;
*  ******************************************************************** *;




log close;
exit;
