version 8.0
log using competingrisk.log, replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*     File-Name:  competingrisk.do                                      *;
*     Date:       April 19, 2005                                        *;
*     Author:     SNG                                                   *;
*     Purpose:    Using new duration dataset and Warwick data           *;
*                 to run competing risk analyses on government duration *;
*     Data Used:  warwick_dataset.dta, coalition.dta                    *;
*     Output File:  competingrisk.log                                   *;
*     Machine:    laptop (compaq)                                       *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set more off;

*     ****************************************************************  *;
*                           (1) Warwick data                            *;
*       Generate single party dummy to match with King's data. Create   *;
*       censoring variable as discussed by Warwick (1994, p. 29)        *;
*       Note that I am using the subset of Warwick's data based on      *;
*       defining governments only by the members officially in the      *;
*       cabinet.  This is not the definition used by Warwick in his     *;
*       analyses (he includes various support parties in parliament).   *;
*       I also exclude cabinets beginning prior to 1946, and cabinets   *;
*       in Luxembourg prior to 1954.                                    *;
*     ****************************************************************  *;

use C:\datasets\warwick_dataset.dta;

sort country delec;
gen dissolution = .;
by country: gen delec_lead = delec[_n+1];
replace dissolution = 0 if delec == delec_lead;
replace dissolution = 1 if delec < delec_lead;
replace dissolution = . if delec_lead == .;
replace dissolution = 1 if endtype==1 & dissolution==.;


gen singleparty = .;
replace singleparty = 0 if npg>1 & npg<10;
replace singleparty = 1 if npg==1;

gen censored = 0;
replace censored = 1 if endtype == 1;
replace censored = 1 if endtype == 4;
replace censored = 1 if endtype == 5;
replace censored = 1 if endtype == 14;
replace censored = 1 if endtype == 15;


gen excluded = 0;
replace excluded = 1 if delec<460;
replace excluded = 1 if delec<540 & country==9;


**********************************************************************  *;
* try to get competing risk analysis                                    *;
*   event=1 if dissolution                                              *;
*   event=2 if replacement                                              *;
**********************************************************************  *;

gen event=.;
replace event=1 if dissolution==1 & endtype~=14;
replace event=2 if dissolution==0 & endtype~=14;


**********************************************************************  *;
*       Governments fail with dissolution                               *;
**********************************************************************  *;

stset dur1, failure(event == 1) ;

stcox invest neff majg pec atts singleparty caretake gfa1r if ftg==1 
& postel==1 & rtallr==1 & excluded==0, efron nohr cluster(country);


**********************************************************************  *;
*       Governments fail with replacement                               *;
**********************************************************************  *;

stset dur1, failure(event == 2) ;

stcox invest neff majg pec atts singleparty caretake gfa1r if ftg==1 
& postel==1 & rtallr==1 & excluded==0, efron nohr cluster(country);;

clear;


**********************************************************************  *;
*       (3) Use new dataset, with variables from PPDA and my data.      *;
**********************************************************************  *;


use C:\datasets\coalition.dta;


gen ciep365 = 0;
replace ciep365=1 if duration > (ciep_years*365 - 365);
replace ciep365=. if duration==.;

gen singleparty = .;
replace singleparty = 0 if govtparties>1 & govtparties<8;
replace singleparty = 1 if govtparties==1;




**********************************************************************  *;
* try to get competing risk analysis                                    *;
*   event=1 if dissolution                                              *;
*   event=2 if replacement                                              *;
**********************************************************************  *;

gen event=.;
replace event=1 if dissolution==1 & duration~=.;
replace event=2 if dissolution==0 & duration~=.;


**********************************************************************  *;
*       Governments fail with dissolution                               *;
**********************************************************************  *;

stset duration, failure(event == 1) ;

stcox investiture enpp2 majority2 pec incbargain singleparty range caretaker
if postelection==1, efron nohr cluster(country1);



**********************************************************************  *;
*       Same model, 90% confidence intervals rather than 95%            *;
**********************************************************************  *;

stcox investiture enpp2 majority2 pec incbargain singleparty range caretaker
if postelection==1, efron nohr cluster(country1) level(90);

**********************************************************************  *;
*       Governments fail with replacement                               *;
**********************************************************************  *;

stset duration, failure(event == 2) ;

stcox investiture enpp2 majority2 pec incbargain singleparty range caretaker
if postelection==1, efron nohr cluster(country1);


**********************************************************************  *;
*                           Descriptive data                            *;
**********************************************************************  *;

sum dissolution if pec==1;
sum dissolution if pec==1 & dissolution==0;
sum dissolution if pec==1 & dissolution==1;

sum dissolution if pec==0 & postelection==1;
sum dissolution if pec==0 & postelection==1 & dissolution==0;
sum dissolution if pec==0 & postelection==1 & dissolution==1;



log close;
exit;
