version 8.0
log using ideology.log, replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*     File-Name:  ideology.do                                           *;
*     Date:       March 31, 2005                                        *;
*     Author:     SNG                                                   *;
*     Purpose:    Using data from the Manifesto Research Group          *;
*           and my own data on pre-electoral coalitions, election       *;
*           years, and whether the government was controlled by a       *;
*           single party. Cabinets taken from Muller and Strom (CCPD)   *;
*           where possible, and from Tsebelis otherwise.                *;
*     Data Used:  ideology.dta                                          *;
*     Output File:  ideology.log                                        *;
*     Machine:    laptop (compaq)                                       *;
*     ****************************************************************  *;
*     ****************************************************************  *;

**********************************************************************  *;
*   I want some simple measures of whether governments that formed      *;
*   based on pre-electoral coalitions are ideologically different       *;
*   (in terms of cohesion, or compatibility) than are governments       *;
*   not based on pre-electoral coalitions.                              *;
**********************************************************************  *;

**********************************************************************  *;
*   The ideology data is taken from the Manifesto Research Group.       *;
*   I followed Warwick (1994, p. 154) in creating two measures of       *;
*   ideological diversity in government coalitions.  First, the range   *;
*   is the absolute distance (in terms of a -100 to +100 left-right     *;
*   ideological scale) between the government party furthest to the     *;
*   and the government party furthest to the right.  Next, the spread   *;
*   measure captures the standard deviation of ideology scores around   *;
*   the government's (weighted) average ideological position.           *;
**********************************************************************  *;

set more off;

use C:\datasets\ideology.dta;

**********************************************************************  *;
*  Get rid of all inter-election governments                            *;
**********************************************************************  *;

drop if legelec==0;

sum range if parties>1;
sum spread if parties>1;

sum range if pec==0 & parties>1;
sum range if pec==1 & parties>1;

sum spread if pec==0 & parties>1;
sum spread if pec==1 & parties>1;

ttest range if parties>1, by(pec);

ttest spread if parties>1, by(pec);
ttest spread if parties>1, by(pec) level(90);


**********************************************************************  *;
*   Now consider whether or not the government coalitions are connected *;
*   or not (i.e., are all members of the government adjacent to one     *;
*   another in the ideological space).  Two measures are used, one      *;
*   based on Muller and Strom 2000 (connected_ms) and the other based   *;
*   on the Manifesto Research Group data used for the other ideological *;
*   measures (connected_mrg).                                           *;
**********************************************************************  *;


sum connected_ms if parties>1 & pec==0 & connected_ms==1;
sum connected_ms if parties>1 & pec==1 & connected_ms==1;


sum connected_mrg if parties>1 & pec==0 & connected_mrg==1;
sum connected_mrg if parties>1 & pec==1 & connected_mrg==1;


log close;
exit;
